.. ProteomicsResultUnifier documentation master file, created by
   sphinx-quickstart on Fri Sep  3 13:50:23 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ProteomicsResultUnifier's documentation!
===================================================

Contents
========

.. toctree::
    :maxdepth: 2
    :numbered:

    introduction
    quick_start
    modules
    advanced_usage
    examples
    contributing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`